<?php

namespace App\Http\Controllers\Admin;

use App\Models\Setting;
use Illuminate\Http\Request;

class SettingController extends MasterController
{
    public function __construct(Setting $model)
    {
        $this->model = $model;
        $this->route = 'setting';
        $this->language = [' بالعربية' => 'ar', ' بالانجليزية' => 'en'];
        $this->module_name = 'قائمة الاعدادات';
        $this->index_fields = ['رقم الجوال الأول' => 'mobile_1', 'رقم الجوال الثانى' => 'mobile_2', 'البريد الإلكترونى' => 'email', 'عن التطبيق' => 'about_us'];
        $this->create_fields = ['رقم الجوال الأول' => 'mobile_1', 'رقم الجوال الثانى' => 'mobile_2', 'البريد الإلكترونى' => 'email', 'عن التطبيق' => 'about_us'];
        $this->update_fields = ['رقم الجوال الأول' => 'mobile_1', 'رقم الجوال الثانى' => 'mobile_2', 'البريد الإلكترونى' => 'email', 'عن التطبيق' => 'about_us'];
        $this->middleware('permission:settings')->only('index');
        $this->middleware('permission:edit_settings')->only('edit');
        $this->middleware('permission:edit_settings')->only('update');
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */


    public function get_setting()
    {
        $row = $this->model->first();
        return View('admin.setting', compact('row'));
    }

    public function update_setting($id, Request $request)
    {
        $this->validate($request, $this->validation_func());
        $setting = $this->model->find($id);
        $setting['meta->phone'] = request('phone');
        $setting['meta->email'] = request('email');
        $setting['meta->address->ar'] = request('address_ar');
        $setting['meta->address->en'] = request('address_en');
        $setting['social->facebook'] = request('facebook');
        $setting['social->instagram'] = request('instagram');
        $setting['social->whatsapp'] = request('whatsapp');
        $setting['social->snapchat'] = request('snapchat');
        $setting['social->twitter'] = request('twitter');
        $setting['about_us->ar'] = request('about_ar');
        $setting['about_us->en'] = request('about_en');
        $setting['policy->ar'] = request('policy_ar');
        $setting['policy->en'] = request('policy_en');
        $setting['pledge->ar'] = request('pledge_ar');
        $setting['pledge->en'] = request('pledge_en');
        $setting['ratio'] = request('ratio');
        $setting['video'] = request('video');


        if (request()->file('logo')) {
            $file = request()->file('logo');
            $destinationPath = 'images/logo/';
            $filename = $file->getClientOriginalName();
            $file->move($destinationPath, $filename);
            $setting->logo = $filename;
        }
        $setting->update();


        return redirect('admin/' . $this->route . '')->with('updated', 'تم التعديل بنجاح');
    }

    public function validation_func()
    {

        $therulesarray['logo'] = 'mimes:png,jpg,jpeg';
        $therulesarray['phone'] = 'required';
        $therulesarray['email'] = 'required';
        $therulesarray['ratio'] = 'required';
        return $therulesarray;
    }
}
